@@ -14,25 +14,24 @@
 #    under the License.
 
 from neutron_lib import exceptions as exc
+from neutron_lib.plugins.ml2 import api
 from oslo_log import log
-import six
 
-from neutron.plugins.ml2 import driver_api as api
+from neutron.plugins.ml2 import driver_api
 
-from midonet.neutron._i18n import _, _LI
 from midonet.neutron.common import constants as const
 
 LOG = log.getLogger(__name__)
 
 
-class UplinkTypeDriver(api.TypeDriver):
+class UplinkTypeDriver(driver_api.ML2TypeDriver):
     """Type driver for Uplink networks
 
     This type driver differentiates uplinks networks from other types.
     """
 
     def __init__(self):
-        LOG.info(_LI("ML2 UplinkTypeDriver initialization complete"))
+        LOG.info("ML2 UplinkTypeDriver initialization complete")
 
     def initialize(self):
         pass
@@ -44,18 +43,18 @@ class UplinkTypeDriver(api.TypeDriver):
         return False
 
     def validate_provider_segment(self, segment):
-        for key, value in six.iteritems(segment):
+        for key, value in segment.items():
             if value and key != api.NETWORK_TYPE:
                 msg = _("%s prohibited for uplink provider network") % key
                 raise exc.InvalidInput(error_message=msg)
 
-    def reserve_provider_segment(self, session, segment):
+    def reserve_provider_segment(self, context, segment):
         return segment
 
-    def allocate_tenant_segment(self, session):
+    def allocate_tenant_segment(self, context):
         return {api.NETWORK_TYPE: const.TYPE_UPLINK}
 
-    def release_segment(self, session, segment):
+    def release_segment(self, context, segment):
         pass
 
     def get_mtu(self, physical):
