@@ -2,8 +2,6 @@
 
 set -e
 
-shift  # ignore "-c"
-
 DIR=$(dirname $0)
 ${DIR}/tox_install_project.sh neutron neutron $*
 ${DIR}/tox_install_project.sh neutron-fwaas neutron_fwaas $*
@@ -16,6 +14,11 @@ ${DIR}/tox_install_project.sh tap-as-a-service neutron_taas $*
 CONSTRAINTS_FILE=$1
 shift
 
+if [ -z "$*" ]; then
+    echo "No packages to be installed."
+    exit 0
+fi
+
 install_cmd="pip install"
 if [ $CONSTRAINTS_FILE != "unconstrained" ]; then
     install_cmd="$install_cmd -c$CONSTRAINTS_FILE"
